==> piwigo-2.7.4.zip: piwigo/plugins/TakeATour/language/da_DK/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['TAT_descrp'] = 'Velkommen! Her finder du alle tilgængelige udflugter, som hjælper dig med at gå på opdagelse i dit Piwigo-galleris funktionalitet.<br>Start udflugten herunder, følg dernæst vejledningen. Klik Næste/Foregående (eller anvend pilene på dit tastatur) for at navigere under udflugten. Hvis du går til en anden administrationsside under udflugten, vil du blive stillet videre til dens aktuelle side. Hvis du er kørt fast og ikke kan afslutte udflugten, vil den blive afsluttet ved at gå til <em>Plugins » Take A Tour</em>.';
$lang['Start the Tour'] = 'Start udflugten';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Tag på en udflugt og opdag hvordan dit Piwigo-galleri fungerer » Gå til tilgængelige udflugter';
$lang['Visit your Piwigo!'] = 'Besøg din Piwigo!';
$lang['takeatour_configpage'] = 'Take A Tour » Udflugtsliste';
$lang['End tour'] = 'Afslut udflugt';
$lang['Next '] = 'Næste';
$lang['Prev'] = 'Forrige';

$lang['First Contact'] = 'Indledning';
$lang['first_contact_descrp'] = 'Udflugten, som er anbefalet til begyndere, gør dig bekendt med Piwigo og de grundlæggende funktioner. Den begynder med at tilføje billeder og fortsætter med håndteringen af dem. Udflugten går videre med håndtering af album og tilladelser, og den slutter  med tilpasning ved hjælp af opsætningensiden, temaerne og plugins.';

$lang['2.7 Tour'] = 'Udflugt i 2.7';
$lang['2_7_0_descrp'] = 'Opdag nyhederne i Piwigo 2.7';

$lang['privacy_descrp'] = 'Denne udflugt præsenterer dig for alle de måder, du kan beskytte et fotografi mod offentlig adgang ved hjælp af rettighedssysteer pr. album og pr. billede, og mod kopiering ved hjælp af billedbeskyttelser.';
$lang['Privacy'] = 'Privatliv';

==> piwigo-16.1.0.zip: piwigo/plugins/TakeATour/language/da_DK/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['TAT_descrp'] = 'Velkommen! Her finder du alle tilgængelige udflugter, som hjælper dig med at gå på opdagelse i dit Piwigo-galleris funktionalitet.<br>Start udflugten herunder, følg dernæst vejledningen. Klik Næste/Foregående (eller anvend pilene på dit tastatur) for at navigere under udflugten. Hvis du går til en anden administrationsside under udflugten, vil du blive stillet videre til dens aktuelle side. Hvis du er kørt fast og ikke kan afslutte udflugten, vil den blive afsluttet ved at gå til <em>Plugins » Take A Tour</em>.';
$lang['Start the Tour'] = 'Start udflugten';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Tag på en udflugt og opdag hvordan dit Piwigo-galleri fungerer » Gå til tilgængelige udflugter';
$lang['Visit your Piwigo!'] = 'Besøg din Piwigo!';
$lang['takeatour_configpage'] = 'Take A Tour » Udflugtsliste';
$lang['End tour'] = 'Afslut udflugt';
$lang['Next '] = 'Næste';
$lang['Prev'] = 'Forrige';

$lang['First Contact'] = 'Indledning';
$lang['first_contact_descrp'] = 'Udflugten, som er anbefalet til begyndere, gør dig bekendt med Piwigo og de grundlæggende funktioner. Den begynder med at tilføje billeder og fortsætter med håndteringen af dem. Udflugten går videre med håndtering af album og tilladelser, og den slutter  med tilpasning ved hjælp af opsætningensiden, temaerne og plugins.';

$lang['2.7 Tour'] = 'Udflugt i 2.7';
$lang['2_7_0_descrp'] = 'Opdag nyhederne i Piwigo 2.7';

$lang['privacy_descrp'] = 'Denne udflugt præsenterer dig for alle de måder, du kan beskytte et fotografi mod offentlig adgang ved hjælp af rettighedssysteer pr. album og pr. billede, og mod kopiering ved hjælp af billedbeskyttelser.';
$lang['Privacy'] = 'Privatliv';
$lang['2.8 Tour'] = 'Udflugt i 2.8';
$lang['2_8_0_descrp'] = 'Opdag nogle af de nye funktioner i Piwigo 2.8. Læs flere oplysninger i <a href="%s">udgivelsesbemærkningerne</a>.';
$lang['config_descrp'] = 'Opsæt dine Piwigo-indstillinger. Opdag temamanageren og vælg din Piwigos udseende.';
$lang['config_name'] = 'Opsætning';
$lang['edit_photos_descrp'] = 'Fotografier er grundelementet i din Piwigo. Se hvordan du kan ændre deres egenskaber, et fotografi ad gangen eller i bundter (batch).';
$lang['edit_photos_name'] = 'Rediger fotografier';
$lang['manage_albums_descrp'] = 'Dit albumhierarki er dit galleris struktur. Lær hvordan de organiseres og hvordan deres egenskaber redigeres.';
$lang['manage_albums_name'] = 'Håndter albummer';
$lang['plugins_descrp'] = 'Plugins er er en hovedelement i Piwigo. Aktiver forskellige funktionalitet gennem nogle få klik, og få Piwigo til at opfylde dine behov.';
$lang['plugins_name'] = 'Plugins';
$lang['2_9_0_descrp'] = 'Opdag nogle af de nye funktioner i Piwigo 2.9. Læs flere oplysninger i <a href="%s">udgivelsesbemærkningerne</a>.';
$lang['2_9_0_name'] = 'Udflugt i 2.9';
